#
# spec file for package cura
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cura
Version:        3.6.0
Release:        1.2
Summary:        3D printer control software
License:        LGPL-3.0-only
Group:          Hardware/Printing
Url:            http://github.com/Ultimaker/Cura
Source0:        Cura-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  python3-devel
BuildRequires:  update-desktop-files
BuildRequires:  uranium >= %version
Requires:       cura-engine >= %version
Requires:       python3-numpy
Requires:       python3-pyserial
Requires:       python3-qt5
Requires:       python3-requests
Requires:       python3-scipy
Requires:       python3-shapely
Requires:       python3-typing
Requires:       uranium >= %version
Recommends:     cura-fdm-materials
Recommends:     python3-zeroconf
# for 3mf plugin
Recommends:     python3-Savitar
BuildArch:      noarch

%description
Cura is a project which aims to be an single software solution for 3D printing.
While it is developed to be used with the Ultimaker 3D printer, it can be used
with other RepRap based designs.

Cura helps setting up an Ultimaker, shows the 3D model, allows for scaling /
positioning, can slice the model to G-Code with editable configuration
settings, and send this G-Code to the 3D printer for printing.

%prep
%setup -q -n Cura-%version
sed -i 's:Version=.*:Version=1.0:; s:Icon=.*:Icon=cura-icon:' cura.desktop.in

%build
CFLAGS="%{optflags}"
export CFLAGS
sed -i 's/PythonInterp 3.5.0/PythonInterp 3.4.0/' CMakeLists.txt cmake/CuraTests.cmake
# Hack, remove LIB_SUFFIX for 64bit, which is correct as cura is pure python (i.e. noarch)
%cmake -DLIB_SUFFIX="" -DCURA_VERSION=%version
make %{?_smp_mflags}

%install
pushd build
%make_install
popd

for x in 128 64 48 32; do
    install -m 755 -d %{buildroot}%{_datadir}/icons/hicolor/${x}x${x}
    install -m 644 icons/cura-${x}.png %{buildroot}%{_datadir}/icons/hicolor/${x}x${x}/cura-icon.png
done

# i18n sources (po/pot) are installed in cura/resources, .mo in uranium/resources
rm -Rf %{buildroot}%{_datadir}/%{name}/resources/i18n
# uranium uses i18n instead of locale for the path to translation files,
# thus we cannot use %%find_lang
echo '%defattr(644,root,root,755)' > %{name}.lang
find %{buildroot}%{_datadir}/uranium -name *.mo | sed '
  s:'%{buildroot}'::; s:\(.*/i18n/\)\([^/]\+\)\(.*mo\):%lang(\2) \1\2\3:' \
  >> %{name}.lang

%fdupes -s %{buildroot}%{_datadir}/%{name}
%suse_update_desktop_file cura Graphics 3DGraphics

%files -f %{name}.lang
%defattr (-,root,root,-)
%license LICENSE
%doc README.md
%{python3_sitelib}/cura
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/mime/packages/cura.xml
%{_datadir}/icons/hicolor
%{_bindir}/cura
%{_prefix}/lib/cura

%changelog
* Fri Nov 16 2018 Adrian Schröter <adrian@suse.de>
- update to version 3.6.0
  https://ultimaker.com/en/products/ultimaker-cura-software/release-notes
* Wed Oct 17 2018 Adrian Schröter <adrian@suse.de>
- update to version 3.5.1
  https://ultimaker.com/en/products/ultimaker-cura-software/release-notes
* Wed Aug  8 2018 jengelh@inai.de
- Do not assume a particular user.
* Mon Aug  6 2018 adrian@suse.de
- add recommends to python3-Savitar for 3mf plugin
* Mon Jul 16 2018 adrian@suse.de
- update to version 3.4.1
  https://ultimaker.com/en/products/ultimaker-cura-software/release-notes
* Mon Jul  9 2018 adrian@suse.de
- update to version 3.3.1
  * Ultimaker S5 support
* Fri Mar 30 2018 bugs@vdm-design.de
- Add runtime dependency to python3-typing
  Cura doens't start without it
* Sat Jan 27 2018 stefan.bruens@rwth-aachen.de
- Fix incorrect install path, make package noarch again
* Sun Jan 14 2018 stefan.bruens@rwth-aachen.de
- Add missing runtime requirement to python3-scipy
* Fri Dec  8 2017 stefan.bruens@rwth-aachen.de
- Fix License, Cura 3.0 and libraries are LGPL-3.0 now
* Thu Dec  7 2017 stefan.bruens@rwth-aachen.de
- Update to version 3.0.3
- Drop no longer needed
  0001-adapt-python-install-dir-to-SUSE-convention.patch
- Use proper RPM Group, Hardware/Printing (Applications/Engineering
  no longer exists)
* Thu Sep 28 2017 stefan.bruens@rwth-aachen.de
- Set required python version to 3.4.0 in *all* cmake files, allow
  builds on Leap 42.3
* Wed Sep 13 2017 stefan.bruens@rwth-aachen.de
- Update to version 2.7.0
* Fri Mar 17 2017 stefan.bruens@rwth-aachen.de
- Removed unused python runtime dependencies
- Recommend (not yet available) python3-zeroconf for UM3
  network discovery/printing
* Thu Mar 16 2017 stefan.bruens@rwth-aachen.de
- Package cura.appdata.xml
- Update RPM URL/Source to official Ultimaker github repositories
- redo and rename fix_build.patch, replace with
  0001-adapt-python-install-dir-to-SUSE-convention.patch
* Wed Mar 15 2017 bugs@vdm-design.de
- Update to version 2.4.0
* Wed Nov 23 2016 stefan.bruens@rwth-aachen.de
- Cleanup specfile:
  * delete .po/.pot files
  * proper packaging of translations (%%lang tag)
  * install icons to hicolor dir
  * removed unnecessary buildrequires
  * delete google-opensans-fonts copy
* Sun Nov  6 2016 bugs@vdm-design.de
- Update to version 2.3.1
* Mon Jun 20 2016 adrian@suse.de
- switch to git master
* Sun Nov 15 2015 boris@steki.net
- updated to latest upstream version 15.04
* Tue Oct  7 2014 boris@steki.net
- Updated to latest upstream version 14.09
* Sun May  4 2014 boris@steki.net
- Development
  * Added an expert parameter for the wipe tower size, and made brim go around the wipe tower
  * Added experimental support for printing with the Doodle3D WiFi box
  * Updated object boundaries for multi-object prints, allows for tighter fitting of objects on the build platform
  * Updated time-estimate to greatly improve accuracy of the estimate.
  * Fixed problem with retractions not happening when they should.
  * Added keyboard control for the 3D window to look around with cursor keys.
- Ultimaker2 - Firmware update - 13.12
  * Fixed the problem where aborting a print did not always home the head.
  * Fixed bug in acceleration planning causing slow moves on rare occasions.
  * Disable the normal menus during USB printing, and support for USB based menus.
  * Disable stepper drivers after print is finished or aborted, so you can manually move the head.
  * Expert feature: Support M907 for setting the motor current.
- Ultimaker Original - Firmware update - 13.12
  * Fixed bug in acceleration planning causing slow moves on rare occasions.
  * Updated to new ErikZalm Marlin base, fixing the long standing slower retraction bug.
* Sat Oct 12 2013 lzwang@suse.com
- Initial package of Cura
